==> activity-center-api-3.6.11-20250110.064550-11-sources.jar: cn/com/duiba/activity/center/api/dto/wanda/GroggeryDto.java <==
package cn.com.duiba.activity.center.api.dto.wanda;

import java.util.Date;

public class GroggeryDto {
    /**
     * 主键
     */
    private Long id;

    /**
     * 酒店编码
     */
    private String groggeryCode;

    /**
     * 酒店名称
     */
    private String groggeryName;

    /**
     * 分佣比例
     */
    private String disRate;

    /**
     * 累计酒店分销商品数
     */
    private Long totalGoodsDisQuantity;

    /**
     * 累计分佣金额（酒店分销）单位分
     */
    private String totalGroggeryDisAmount;

    /**
     * 累计分佣金额（员工分销）单位分
     */
    private String totalEmployeeDisAmount;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getGroggeryCode() {
        return groggeryCode;
    }

    public void setGroggeryCode(String groggeryCode) {
        this.groggeryCode = groggeryCode;
    }

    public String getGroggeryName() {
        return groggeryName;
    }

    public void setGroggeryName(String groggeryName) {
        this.groggeryName = groggeryName;
    }

    public String getDisRate() {
        return disRate;
    }

    public void setDisRate(String disRate) {
        this.disRate = disRate;
    }

    public Long getTotalGoodsDisQuantity() {
        return totalGoodsDisQuantity;
    }

    public void setTotalGoodsDisQuantity(Long totalGoodsDisQuantity) {
        this.totalGoodsDisQuantity = totalGoodsDisQuantity;
    }

    public String getTotalGroggeryDisAmount() {
        return totalGroggeryDisAmount;
    }

    public void setTotalGroggeryDisAmount(String totalGroggeryDisAmount) {
        this.totalGroggeryDisAmount = totalGroggeryDisAmount;
    }

    public String getTotalEmployeeDisAmount() {
        return totalEmployeeDisAmount;
    }

    public void setTotalEmployeeDisAmount(String totalEmployeeDisAmount) {
        this.totalEmployeeDisAmount = totalEmployeeDisAmount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-3.6.26-20250907.113250-10-sources.jar: cn/com/duiba/activity/center/api/dto/wanda/GroggeryDto.java <==
package cn.com.duiba.activity.center.api.dto.wanda;

import java.io.Serializable;
import java.util.Date;

public class GroggeryDto implements Serializable {
    /**
     * 主键
     */
    private Long id;

    /**
     * 酒店编码
     */
    private String groggeryCode;

    /**
     * 酒店经营管控代码
     */
    private String groggeryBizCode;

    /**
     * 酒店名称
     */
    private String groggeryName;

    /**
     * 分佣比例
     */
    private String disRate;

    /**
     * 累计酒店分销商品数
     */
    private Long totalGoodsDisQuantity;

    /**
     * 累计分佣金额（酒店分销）单位分
     */
    private Long totalGroggeryDisAmount;

    /**
     * 累计分佣金额（员工分销）单位分
     */
    private Long totalEmployeeDisAmount;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getGroggeryCode() {
        return groggeryCode;
    }

    public void setGroggeryCode(String groggeryCode) {
        this.groggeryCode = groggeryCode;
    }

    public String getGroggeryBizCode() {
        return groggeryBizCode;
    }

    public void setGroggeryBizCode(String groggeryBizCode) {
        this.groggeryBizCode = groggeryBizCode;
    }

    public String getGroggeryName() {
        return groggeryName;
    }

    public void setGroggeryName(String groggeryName) {
        this.groggeryName = groggeryName;
    }

    public String getDisRate() {
        return disRate;
    }

    public void setDisRate(String disRate) {
        this.disRate = disRate;
    }

    public Long getTotalGoodsDisQuantity() {
        return totalGoodsDisQuantity;
    }

    public void setTotalGoodsDisQuantity(Long totalGoodsDisQuantity) {
        this.totalGoodsDisQuantity = totalGoodsDisQuantity;
    }

    public Long getTotalGroggeryDisAmount() {
        return totalGroggeryDisAmount;
    }

    public void setTotalGroggeryDisAmount(Long totalGroggeryDisAmount) {
        this.totalGroggeryDisAmount = totalGroggeryDisAmount;
    }

    public Long getTotalEmployeeDisAmount() {
        return totalEmployeeDisAmount;
    }

    public void setTotalEmployeeDisAmount(Long totalEmployeeDisAmount) {
        this.totalEmployeeDisAmount = totalEmployeeDisAmount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
